Contributor License Agreement
=============================

Summary and scope
-----------------

It may seem self-evident that contributing to a project distributed under an open-source license is an implicit permission to anyone for using the contributed code.
However, a formal Contributor License Agreements (CLA) makes contribution terms explicit and provides the project maintainers a record of your agreement to those terms.

A wide range of terms exist in other CLAs, including waiver of moral rights, consequential damages waiver, as-is disclaimer, etc. For this project, we follow the more bare-boned GitHub CLA, which focuses on the three most important clauses: copyright, patent, and source of contribution.

In short, by signing this Contributor License Agreement, you confirm that:

1. Anyone can use your contributions anywhere, for free, forever.
2. Your contributions do not infringe on anyone else's rights.


Definition of terms
-------------------

The following terms are used throughout this agreement:

 - **You** - the person or legal entity including its affiliates asked
   to accept this agreement. An affiliate is any entity that controls
   or is controlled by the legal entity, or is under common control with it.
 - **Project** - the repositories ``message_ix`` and ``ixmp``, and
   any derived repositories, projects, or software/code packages.
 - **Contribution** - any type of work that is submitted to a Project,
   including any modifications or additions to existing work.
 - **Submitted** - conveyed to a Project via a pull request, commit, issue,
   or any form of electronic, written, or verbal communication with GitHub,
   contributors or maintainers.

1. Grant of Copyright License
-----------------------------

Subject to the terms and conditions of this agreement, You grant to
the Projects’ maintainers, contributors and users a perpetual, worldwide,
unlimited in scope, non-exclusive, no-charge, royalty-free, irrevocable
copyright license to, in particular without being limited to,
reproduce, prepare derivative works of, publicly display, make available,
sublicense, and distribute Your contributions and such derivative works
in whole or in part. Except for this license, You reserve all moral rights,
title, and interest in your contributions.

2. Grant of Patent License
--------------------------

Subject to the terms and conditions of this agreement, You grant to
the Projects’ maintainers, contributors and users a perpetual, worldwide,
unlimited in scope, non-exclusive, no-charge, royalty-free, irrevocable
(except as stated in this section) patent license to make, have made, use,
offer to sell, sell, import, and otherwise transfer your contributions, in
whole or in part, where such license applies only to those patent claims
licensable by you that are necessarily infringed by your contribution or
by combination of your contribution with the project
to which this contribution was submitted.

If any entity institutes patent litigation - including cross-claim or
counterclaim in a lawsuit - against You alleging that your contribution or
any project it was submitted to constitutes or is responsible for direct or
contributory patent infringement, then any patent licenses granted to that entity
under this agreement shall terminate as of the date such litigation is filed.

3. Source of Contribution
-------------------------

Your contribution is either your original creation or based upon previous work
that, to the best of your knowledge, is covered under an appropriate open
source license. You assure that you are legally entitled to submit your
contribution and grant the above license, or you have clearly identified the
source of the contribution and any license or other restriction (like related
patents, trademarks, and license agreements) of which you are personally aware.
If your employer(s) or employee(s) have rights to intellectual property that
you create, you represent that you have received permission to make the
contributions on behalf of that employer/employee, or that
your employer/employee has waived such rights for your contributions.

Should the licensor be held responsible for any violation of intellectual
property right in relation to your contribution, you shall be fully liable
for damages that may arise.

Reference and License
---------------------

This Contributor License Agreement and the introductory text is adapted from
the `GitHub Contributor License Agreement`_, Version 298f3afd updated August 9, 2017.
GitHub granted a `CC-BY-4.0 License`_ to IIASA to use and modify the text of the CLA.

.. _`GitHub Contributor License Agreement` : https://cla.github.com/agreement
.. _`CC-BY-4.0 License` : https://creativecommons.org/licenses/by/4.0/
